'''_1835.py

CVTBeltConnection
'''


from mastapy._internal.implicit import overridable
from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets import _1830
from mastapy._internal.python_net import python_net_import

_CVT_BELT_CONNECTION = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets', 'CVTBeltConnection')


__docformat__ = 'restructuredtext en'
__all__ = ('CVTBeltConnection',)


class CVTBeltConnection(_1830.BeltConnection):
    '''CVTBeltConnection

    This is a mastapy class.
    '''

    TYPE = _CVT_BELT_CONNECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CVTBeltConnection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def belt_efficiency(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'BeltEfficiency' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.BeltEfficiency) if self.wrapped.BeltEfficiency else None

    @belt_efficiency.setter
    def belt_efficiency(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.BeltEfficiency = value
