'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._970 import CustomSplineHalfDesign
    from ._971 import CustomSplineJointDesign
    from ._972 import DetailedSplineJointSettings
    from ._973 import DIN5480SplineHalfDesign
    from ._974 import DIN5480SplineJointDesign
    from ._975 import DudleyEffectiveLengthApproximationOption
    from ._976 import FitTypes
    from ._977 import GBT3478SplineHalfDesign
    from ._978 import GBT3478SplineJointDesign
    from ._979 import HeatTreatmentTypes
    from ._980 import ISO4156SplineHalfDesign
    from ._981 import ISO4156SplineJointDesign
    from ._982 import JISB1603SplineJointDesign
    from ._983 import ManufacturingTypes
    from ._984 import Modules
    from ._985 import PressureAngleTypes
    from ._986 import RootTypes
    from ._987 import SAEFatigueLifeFactorTypes
    from ._988 import SAESplineHalfDesign
    from ._989 import SAESplineJointDesign
    from ._990 import SAETorqueCycles
    from ._991 import SplineDesignTypes
    from ._992 import FinishingMethods
    from ._993 import SplineFitClassType
    from ._994 import SplineFixtureTypes
    from ._995 import SplineHalfDesign
    from ._996 import SplineJointDesign
    from ._997 import SplineMaterial
    from ._998 import SplineRatingTypes
    from ._999 import SplineToleranceClassTypes
    from ._1000 import StandardSplineHalfDesign
    from ._1001 import StandardSplineJointDesign
