'''_114.py

PackagingLimits
'''


from mastapy._internal.implicit import overridable
from mastapy._internal import constructor
from mastapy.utility import _1132
from mastapy._internal.python_net import python_net_import

_PACKAGING_LIMITS = python_net_import('SMT.MastaAPI.Geometry', 'PackagingLimits')


__docformat__ = 'restructuredtext en'
__all__ = ('PackagingLimits',)


class PackagingLimits(_1132.IndependentReportablePropertiesBase['PackagingLimits']):
    '''PackagingLimits

    This is a mastapy class.
    '''

    TYPE = _PACKAGING_LIMITS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PackagingLimits.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def maximum_x(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MaximumX' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MaximumX) if self.wrapped.MaximumX else None

    @maximum_x.setter
    def maximum_x(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.MaximumX = value

    @property
    def minimum_x(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MinimumX' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MinimumX) if self.wrapped.MinimumX else None

    @minimum_x.setter
    def minimum_x(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.MinimumX = value

    @property
    def maximum_y(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MaximumY' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MaximumY) if self.wrapped.MaximumY else None

    @maximum_y.setter
    def maximum_y(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.MaximumY = value

    @property
    def minimum_y(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MinimumY' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MinimumY) if self.wrapped.MinimumY else None

    @minimum_y.setter
    def minimum_y(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.MinimumY = value

    @property
    def maximum_z(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MaximumZ' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MaximumZ) if self.wrapped.MaximumZ else None

    @maximum_z.setter
    def maximum_z(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.MaximumZ = value

    @property
    def minimum_z(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'MinimumZ' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.MinimumZ) if self.wrapped.MinimumZ else None

    @minimum_z.setter
    def minimum_z(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0)
        self.wrapped.MinimumZ = value
