'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._715 import ZerolBevelGearDesign
    from ._716 import ZerolBevelGearMeshDesign
    from ._717 import ZerolBevelGearSetDesign
    from ._718 import ZerolBevelMeshedGearDesign
