'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3597 import AbstractAssemblyCompoundParametricStudyTool
    from ._3598 import AbstractShaftOrHousingCompoundParametricStudyTool
    from ._3599 import AGMAGleasonConicalGearCompoundParametricStudyTool
    from ._3600 import AGMAGleasonConicalGearMeshCompoundParametricStudyTool
    from ._3601 import AGMAGleasonConicalGearSetCompoundParametricStudyTool
    from ._3602 import AssemblyCompoundParametricStudyTool
    from ._3603 import BearingCompoundParametricStudyTool
    from ._3604 import BeltConnectionCompoundParametricStudyTool
    from ._3605 import BeltDriveCompoundParametricStudyTool
    from ._3606 import BevelDifferentialGearCompoundParametricStudyTool
    from ._3607 import BevelDifferentialGearMeshCompoundParametricStudyTool
    from ._3608 import BevelDifferentialGearSetCompoundParametricStudyTool
    from ._3609 import BevelDifferentialPlanetGearCompoundParametricStudyTool
    from ._3610 import BevelDifferentialSunGearCompoundParametricStudyTool
    from ._3611 import BevelGearCompoundParametricStudyTool
    from ._3612 import BevelGearMeshCompoundParametricStudyTool
    from ._3613 import BevelGearSetCompoundParametricStudyTool
    from ._3614 import BoltCompoundParametricStudyTool
    from ._3615 import BoltedJointCompoundParametricStudyTool
    from ._3616 import ClutchCompoundParametricStudyTool
    from ._3617 import ClutchConnectionCompoundParametricStudyTool
    from ._3618 import ClutchHalfCompoundParametricStudyTool
    from ._3619 import CoaxialConnectionCompoundParametricStudyTool
    from ._3620 import ComponentCompoundParametricStudyTool
    from ._3621 import ConceptCouplingCompoundParametricStudyTool
    from ._3622 import ConceptCouplingConnectionCompoundParametricStudyTool
    from ._3623 import ConceptCouplingHalfCompoundParametricStudyTool
    from ._3624 import ConceptGearCompoundParametricStudyTool
    from ._3625 import ConceptGearMeshCompoundParametricStudyTool
    from ._3626 import ConceptGearSetCompoundParametricStudyTool
    from ._3627 import ConicalGearCompoundParametricStudyTool
    from ._3628 import ConicalGearMeshCompoundParametricStudyTool
    from ._3629 import ConicalGearSetCompoundParametricStudyTool
    from ._3630 import ConnectionCompoundParametricStudyTool
    from ._3631 import ConnectorCompoundParametricStudyTool
    from ._3632 import CouplingCompoundParametricStudyTool
    from ._3633 import CouplingConnectionCompoundParametricStudyTool
    from ._3634 import CouplingHalfCompoundParametricStudyTool
    from ._3635 import CVTBeltConnectionCompoundParametricStudyTool
    from ._3636 import CVTCompoundParametricStudyTool
    from ._3637 import CVTPulleyCompoundParametricStudyTool
    from ._3638 import CylindricalGearCompoundParametricStudyTool
    from ._3639 import CylindricalGearMeshCompoundParametricStudyTool
    from ._3640 import CylindricalGearSetCompoundParametricStudyTool
    from ._3641 import CylindricalPlanetGearCompoundParametricStudyTool
    from ._3642 import DatumCompoundParametricStudyTool
    from ._3643 import ExternalCADModelCompoundParametricStudyTool
    from ._3644 import FaceGearCompoundParametricStudyTool
    from ._3645 import FaceGearMeshCompoundParametricStudyTool
    from ._3646 import FaceGearSetCompoundParametricStudyTool
    from ._3647 import FlexiblePinAssemblyCompoundParametricStudyTool
    from ._3648 import GearCompoundParametricStudyTool
    from ._3649 import GearMeshCompoundParametricStudyTool
    from ._3650 import GearSetCompoundParametricStudyTool
    from ._3651 import GuideDxfModelCompoundParametricStudyTool
    from ._3652 import HypoidGearCompoundParametricStudyTool
    from ._3653 import HypoidGearMeshCompoundParametricStudyTool
    from ._3654 import HypoidGearSetCompoundParametricStudyTool
    from ._3655 import ImportedFEComponentCompoundParametricStudyTool
    from ._3656 import InterMountableComponentConnectionCompoundParametricStudyTool
    from ._3657 import KlingelnbergCycloPalloidConicalGearCompoundParametricStudyTool
    from ._3658 import KlingelnbergCycloPalloidConicalGearMeshCompoundParametricStudyTool
    from ._3659 import KlingelnbergCycloPalloidConicalGearSetCompoundParametricStudyTool
    from ._3660 import KlingelnbergCycloPalloidHypoidGearCompoundParametricStudyTool
    from ._3661 import KlingelnbergCycloPalloidHypoidGearMeshCompoundParametricStudyTool
    from ._3662 import KlingelnbergCycloPalloidHypoidGearSetCompoundParametricStudyTool
    from ._3663 import KlingelnbergCycloPalloidSpiralBevelGearCompoundParametricStudyTool
    from ._3664 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundParametricStudyTool
    from ._3665 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundParametricStudyTool
    from ._3666 import MassDiscCompoundParametricStudyTool
    from ._3667 import MeasurementComponentCompoundParametricStudyTool
    from ._3668 import MountableComponentCompoundParametricStudyTool
    from ._3669 import OilSealCompoundParametricStudyTool
    from ._3670 import PartCompoundParametricStudyTool
    from ._3671 import PartToPartShearCouplingCompoundParametricStudyTool
    from ._3672 import PartToPartShearCouplingConnectionCompoundParametricStudyTool
    from ._3673 import PartToPartShearCouplingHalfCompoundParametricStudyTool
    from ._3674 import PlanetaryConnectionCompoundParametricStudyTool
    from ._3675 import PlanetaryGearSetCompoundParametricStudyTool
    from ._3676 import PlanetCarrierCompoundParametricStudyTool
    from ._3677 import PointLoadCompoundParametricStudyTool
    from ._3678 import PowerLoadCompoundParametricStudyTool
    from ._3679 import PulleyCompoundParametricStudyTool
    from ._3680 import RollingRingAssemblyCompoundParametricStudyTool
    from ._3681 import RollingRingCompoundParametricStudyTool
    from ._3682 import RollingRingConnectionCompoundParametricStudyTool
    from ._3683 import RootAssemblyCompoundParametricStudyTool
    from ._3684 import ShaftCompoundParametricStudyTool
    from ._3685 import ShaftHubConnectionCompoundParametricStudyTool
    from ._3686 import ShaftToMountableComponentConnectionCompoundParametricStudyTool
    from ._3687 import SpecialisedAssemblyCompoundParametricStudyTool
    from ._3688 import SpiralBevelGearCompoundParametricStudyTool
    from ._3689 import SpiralBevelGearMeshCompoundParametricStudyTool
    from ._3690 import SpiralBevelGearSetCompoundParametricStudyTool
    from ._3691 import SpringDamperCompoundParametricStudyTool
    from ._3692 import SpringDamperConnectionCompoundParametricStudyTool
    from ._3693 import SpringDamperHalfCompoundParametricStudyTool
    from ._3694 import StraightBevelDiffGearCompoundParametricStudyTool
    from ._3695 import StraightBevelDiffGearMeshCompoundParametricStudyTool
    from ._3696 import StraightBevelDiffGearSetCompoundParametricStudyTool
    from ._3697 import StraightBevelGearCompoundParametricStudyTool
    from ._3698 import StraightBevelGearMeshCompoundParametricStudyTool
    from ._3699 import StraightBevelGearSetCompoundParametricStudyTool
    from ._3700 import StraightBevelPlanetGearCompoundParametricStudyTool
    from ._3701 import StraightBevelSunGearCompoundParametricStudyTool
    from ._3702 import SynchroniserCompoundParametricStudyTool
    from ._3703 import SynchroniserHalfCompoundParametricStudyTool
    from ._3704 import SynchroniserPartCompoundParametricStudyTool
    from ._3705 import SynchroniserSleeveCompoundParametricStudyTool
    from ._3706 import TorqueConverterCompoundParametricStudyTool
    from ._3707 import TorqueConverterConnectionCompoundParametricStudyTool
    from ._3708 import TorqueConverterPumpCompoundParametricStudyTool
    from ._3709 import TorqueConverterTurbineCompoundParametricStudyTool
    from ._3710 import UnbalancedMassCompoundParametricStudyTool
    from ._3711 import VirtualComponentCompoundParametricStudyTool
    from ._3712 import WormGearCompoundParametricStudyTool
    from ._3713 import WormGearMeshCompoundParametricStudyTool
    from ._3714 import WormGearSetCompoundParametricStudyTool
    from ._3715 import ZerolBevelGearCompoundParametricStudyTool
    from ._3716 import ZerolBevelGearMeshCompoundParametricStudyTool
    from ._3717 import ZerolBevelGearSetCompoundParametricStudyTool
